#ifndef TargetDetection_h
#define TargetDetection_h

#include "Arduino.h"
#include "McKenzie.h"

class TargetDetection {
  /*  
    *******************************
    * Infra Red Target Detection  *
    *******************************
  */

  public:
    TargetDetection (int inPin, int hitLevel, int hitInterval, int hitCycles, int hitResetTime);
    bool check(); //Check input for hit function
    bool pulseDetect; //
    int inPin; //Pin for Target input 
    int hitLevel; //Increase in target analog input level that represents possible hit
    int hitCycles; //Number of cycles at frequency that have to be detected for hit
    int hitInterval; //ON to ON and OFF to OFF interval of IR Pulse from other tank
    int hitResetTime;

  private:
    int targetLevel; //Target analog input level (0-1023)
    int lastTargetLevel; //Target level last scan
    long onTimes[800]; //Array of processor time when target level went from OFF to ON
    long offTimes[800]; //Array of processor time when target level went from ON to OFF
    int onLevel; //Target level that represents the transition from OFF not ON
    long onInterval; //Time interval bewteen ON transutions
    long offInterval; //Time interval between OFF transitions
    int detectIndex=0; //Index for onTimes and offTimes array
    int detectCount; //Number of intervals that are within the bandwidth before timer resets count
    Timer_rlm detectReset{2000}; //Timer for reseting detect index
    Timer_rlm detectTime{hitResetTime}; //Timer for reseting detectCount
    bool oneShot1;
    bool oneShot2; 
    int intervalBand = 5; //Allowable deviation from detected intervals for positive detection
};

#endif
